@@ -20,8 +20,8 @@ class Program : public QObject
     Q_PROPERTY(ProgramId id READ id CONSTANT)
     Q_PROPERTY(QString url READ url CONSTANT)
     Q_PROPERTY(QString title READ title CONSTANT)
-    Q_PROPERTY(QString description READ description CONSTANT)
-    Q_PROPERTY(bool descriptionFetched READ descriptionFetched CONSTANT)
+    Q_PROPERTY(QString description READ description WRITE setDescription NOTIFY descriptionChanged)
+    Q_PROPERTY(bool descriptionFetched READ descriptionFetched WRITE setDescriptionFetched NOTIFY descriptionFetchedChanged)
     Q_PROPERTY(QDateTime start READ start CONSTANT)
     Q_PROPERTY(QDateTime stop READ stop CONSTANT)
     Q_PROPERTY(QString subtitle READ subtitle CONSTANT)
@@ -43,6 +43,13 @@ public:
     QString subtitle() const;
     QVector<QString> categories() const;
 
+    void setDescription(const QString &description);
+    void setDescriptionFetched(bool descriptionFetched);
+
+Q_SIGNALS:
+    void descriptionChanged(const QString &description);
+    void descriptionFetchedChanged(bool descriptionFetched);
+
 private:
     ProgramData m_data;
 };
